/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.render;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import java.awt.Rectangle;
import java.awt.geom.Point2D;
import org.jdesktop.swingx.mapviewer.GeoPosition;

/**
 * Implementations of this class are able to translate pixels to geo coordinates an visa versa
 * @author Merijn Zengers
 */
public interface GeoTranslator {
    
    /**
     * Translates geo Coordinate to pixel 
     * @param canvas the canvas on which the coordinate is drawn
     * @param boundingBox the bounding box geometry to scale the coordinate to
     * @param coordinate the coordinate to translate to pixels
     * @return Point2D the calculated pixel
     */
    public Point2D geoToPixel(Rectangle canvas, Geometry boundingBox, Coordinate coordinate);
    
    /**
     * Translates pixels to GeoPosition
     * @param canvas the canvas the pixel is on
     * @param boundingBox the bounding box of the geometry
     * @param pixel the pixel to translate
     * @return the calculated GeoPosition
     */
    public GeoPosition pixelToGeo(Rectangle canvas, Geometry boundingBox, Point2D pixel);

    
}
