/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.render;

import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import java.awt.*;
import java.awt.geom.Point2D;

/**
 * Renders points 
 * @author Timon Veenstra
 */
public class PointRenderer extends GeometryRenderer<Point> {

    private Font font = new Font("Dialog", Font.BOLD, 12);
    private double alpha = (100 - (double) 0 /*transparancy*/) / 100;
    private static int STROKE_WIDTH = 2; // stroke of the rectangle surrounding the label (pixels)

    @Override
    public void render(Point geometry, Geometry boundingBox, Rectangle canvas, GeoTranslator translator, Graphics2D g) {
        com.vividsolutions.jts.geom.Point centroid = geometry.getCentroid();
        final Point2D pointOnMap = translator.geoToPixel(canvas, boundingBox, centroid.getCoordinate());


        if (canvas.contains(pointOnMap)) {
            final int x = (int) (pointOnMap.getX() - canvas.x);
            final int y = (int) (pointOnMap.getY() - canvas.y);

            g.setFont(font);
            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, new Float(alpha)));
            g.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
            g.setStroke(new BasicStroke(STROKE_WIDTH, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));

            Rectangle rect = new Rectangle(4, 4, 4, 4);
            rect.setLocation(x, y);
            g.fill(rect);
        }
    }
}
